@@ -1,4 +1,4 @@
-from rest_framework.serializers import CharField, Serializer
+from rest_framework.serializers import Serializer
 
 from .typing import Any, Dict, List, Type, Union
 
@@ -6,7 +6,6 @@ from .typing import Any, Dict, List, Type, Union
 __all__ = [
     "EmptySerializer",
     "MockSerializer",
-    "DetailSerializer",
 ]
 
 
@@ -15,11 +14,6 @@ class EmptySerializer(Serializer):  # pylint: disable=W0223
     pass
 
 
-class DetailSerializer(Serializer):  # pylint: disable=W0223
-    # Serializer for error responses
-    detail = CharField()
-
-
 class MockSerializer(Serializer):  # pylint: disable=W0223
     # Serializer that simply passes initial data to output.
 
