@@ -8,6 +8,7 @@ from django.conf import settings
 from django.core.cache import cache
 from django.utils.translation import get_language as current_language
 from django.utils.translation import override
+from pydantic import BaseModel  # pylint: disable=E0611
 from rest_framework.request import Request
 from rest_framework.response import Response
 from rest_framework.serializers import BaseSerializer
@@ -26,6 +27,7 @@ from .typing import (
     SerializerType,
     T,
     Tuple,
+    TypeGuard,
     Union,
     ViewMethod,
 )
@@ -36,10 +38,11 @@ if TYPE_CHECKING:
 
 
 __all__ = [
-    "sentinel",
+    "Sentinel",
     "get_language",
     "translate",
     "is_serializer_class",
+    "is_pydantic_model",
     "cache_pipeline_logic",
     "run_in_thread",
     "run_parallel",
@@ -47,17 +50,21 @@ __all__ = [
 ]
 
 
-class sentinel:  # pylint: disable=C0103
+class Sentinel:
     """Sentinel value."""
 
 
 available_languages: List[str] = [key for (key, value) in settings.LANGUAGES]
 
 
-def is_serializer_class(obj: Any) -> bool:
+def is_serializer_class(obj: Any) -> TypeGuard[BaseSerializer]:
     return isinstance(obj, type) and issubclass(obj, BaseSerializer)
 
 
+def is_pydantic_model(obj: Any) -> TypeGuard[BaseModel]:
+    return isinstance(obj, type) and issubclass(obj, BaseModel)
+
+
 def get_language(request: Request) -> str:
     """Get language based on request Accept-Language header or 'lang' query parameter."""
     lang: Optional[str] = request.query_params.get("lang")
